from distutils.core import setup
from setuptools import setup

setup(
    name       = 'ls_coach',
    version    = '1.0.1',
    py_modules = ['ls_coach'],
    author     = 'lecsim',
    author_email = 'lechler@gmx.com',
    url = 'http://www.headfirstlabs.com',
    description = 'A simple printer of nested lists',
)
